@@ -86,10 +86,12 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     __slots__ = account_fields
 
     mutable_attributes = account_mutable_fields
-    post_fields = ['address_city', 'address_street', 'country', 'custom_color_header', 'limit_levels_max',
-                   'limit_pages_max', 'custom_color_menu', 'name', 'phone', 'address_zip', 'pref_email_support',
-                   'custom_domain', 'address_state', 'custom_support_email', 'custom_support_phone', 'timezone',
-                   'finance_vat', 'splunk_enabled', 'active']
+    post_fields = [
+        'address_city', 'address_street', 'country', 'custom_color_header', 'limit_levels_max',
+        'limit_pages_max', 'custom_color_menu', 'name', 'phone', 'address_zip', 'pref_email_support',
+        'custom_domain', 'address_state', 'custom_support_email', 'custom_support_phone', 'timezone',
+        'finance_vat', 'splunk_enabled', 'active'
+    ]
 
     def __init__(self, account_data: dict):
         self.id = account_data.get("id")
@@ -179,7 +181,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def load_projects(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProject]:
-        """Loads projects into current instance
+        """
+        Loads projects into current instance
 
         >>> self.load_projects()
         [[0 1] www.test.com Project, [0 2] www.test2.com Project]
@@ -203,7 +206,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def load_account_users(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List['deepcrawl.accounts_users.DeepCrawlUser']:
-        """Loads account users into current instance
+        """
+        Loads account users into current instance
 
         >>> self.load_account_users()
         [FirstName1 LastName1 email1@localhost.com,
@@ -223,7 +227,9 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         :return:
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        self.account_users: List['deepcrawl.accounts_users.DeepCrawlUser'] = connection.get_account_users(self.id, filters=filters, **kwargs)
+        self.account_users: List['deepcrawl.accounts_users.DeepCrawlUser'] = connection.get_account_users(
+            self.id, filters=filters, **kwargs
+        )
         return self.account_users
 
     """
@@ -231,7 +237,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     """
 
     def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.accounts.DeepCrawlAccount':
-        """Save account instance
+        """
+        Save account instance
 
         * if the instance id is None then the account will be created
         * if the instance id is not None then the account will be updated
@@ -253,7 +260,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def refresh(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.accounts.DeepCrawlAccount':
-        """Makes a call to DeepCrawl in order to refresh the current instance.
+        """
+        Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
         [0] DeepCrawlAccount
@@ -272,7 +280,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def update(
             self, account_settings, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.accounts.DeepCrawlAccount':
-        """Updates an instance with account_settings
+        """
+        Updates an instance with account_settings
 
         >>> self.update(account_settings)
         [0] DeepCrawlAccount
@@ -299,7 +308,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List['deepcrawl.accounts_users.DeepCrawlUser']:
-        """Get account users
+        """
+        Get account users
 
         * use_cache=True > get_account_users will return cached account_users or will do a call to DeepCrawl if account_users attribute is empty.
         * use_cache=False > get_account_users will call DeepCrawl api and will override account_users attribute.
@@ -327,7 +337,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def get_account_user(
             self, uid: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.accounts_users.DeepCrawlUser':
-        """Get a user using the user id
+        """
+        Get a user using the user id
 
         >>> self.get_account_user(1)
         FirstName1 LastName1 email1@localhost.com
@@ -343,7 +354,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         return connection.get_account_user(self.id, uid)
 
     def remove_account_user(self, uid: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
-        """Remove user from account
+        """
+        Remove user from account
 
         >>> response = connection.remove_account_user(1, 0)
         >>> response.status_code
@@ -366,7 +378,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def create_project(
             self, project_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProject:
-        """Create project.
+        """
+        Create project.
         Project settings argument can be dict or a ProjectSettings instance.
 
         >>> self.create_project(project_settings)
@@ -385,7 +398,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def get_project(
             self, project_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProject:
-        """Get Project
+        """
+        Get Project
 
         >>> self.get_project(1)
         [0 1] www.test.com Project
@@ -404,7 +418,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             self, project_id: Union[int, str], settings: dict,
             connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProject:
-        """Update the project settings.
+        """
+        Update the project settings.
         Settings argument can be dict or a ProjectSettings instance.
 
         >>> self.update_project_settings(1, settings)
@@ -425,7 +440,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def delete_project(
             self, project_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> requests.Response:
-        """Delete project
+        """
+        Delete project
 
         >>> response = self.delete_project(1)
         >>> response.status_code
@@ -444,7 +460,8 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProject]:
-        """Get projects
+        """
+        Get projects
 
         * use_cache=True > get_projects will return cached projects or will do a call to DeepCrawl if projects attribute is empty.
         * use_cache=False > get_projects will call DeepCrawl api and will override projects attribute.
