@@ -1,7 +1,7 @@
 import json
 import re
 import time
-from typing import Optional, List
+from typing import List, Optional
 
 import requests
 from requests.auth import HTTPBasicAuth
