@@ -2,16 +2,16 @@
 Crawl
 =====
 """
-from typing import Union, Optional, List
+from typing import List, Optional, Union
 
 from requests import Response
 
 import deepcrawl
 from deepcrawl.downloads.download import DeepCrawlCrawlDownloads
 from deepcrawl.reports.report import DeepCrawlReport
+from deepcrawl.sitemaps.sitemap import DeepCrawlCrawlSitemap
 from deepcrawl.statistics.statistic import DeepCrawlCrawlStatistic
-from deepcrawl.utils import ImmutableAttributesMixin
-from deepcrawl.utils import safe_string_to_datetime
+from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
 
 crawl_extra_fields = (
     'id',
@@ -20,7 +20,8 @@ crawl_extra_fields = (
     'reports',
     'reports_changes',
     'downloads',
-    'statistics'
+    'statistics',
+    'sitemaps'
 )
 
 crawl_mutable_fields = crawl_extra_fields + (
@@ -87,6 +88,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         self.reports_changes = []
         self.downloads = []
         self.statistics = []
+        self.sitemaps = []
 
         # attributes
         self.crawling_at = safe_string_to_datetime(crawl_data.get('crawling_at'))
@@ -156,7 +158,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def load_reports(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlReport]:
-        """Loads reports into current instance
+        """
+        Loads reports into current instance
 
         >>> self.load_reports()
         [[0 1 2] 4:duplicate_body_content:basic,
@@ -181,7 +184,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def load_reports_changes(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlReport]:
-        """Loads reports changes into current instance
+        """
+        Loads reports changes into current instance
 
         >>> self.load_reports_changes()
         [[0 1 2] 4:duplicate_body_content:basic,
@@ -209,7 +213,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def load_downloads(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawlDownloads]:
-        """Loads reports downloads into current instance
+        """
+        Loads reports downloads into current instance
 
         >>> self.load_downloads()
         [<deepcrawl.downloads.download.DeepCrawlCrawlDownloads at 0x108a20600>,
@@ -237,7 +242,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def load_statistics(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawlStatistic]:
-        """Loads statistics into current instance
+        """
+        Loads statistics into current instance
 
         >>> self.load_statistics()
         [URL Breakdown, Web Crawl Depth]
@@ -259,12 +265,39 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         )
         return self.statistics
 
+    def load_crawl_sitemaps(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlSitemap]:
+        """
+        Loads sitemaps into current instance
+
+        >>> self.load_sitemaps()
+        [xSbcfwBTi, aWimWxmnc]
+        >>> self.sitemaps
+        [xSbcfwBTi, aWimWxmnc]
+
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: list of sitemaps
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        self.sitemaps = connection.get_crawl_sitemaps(
+            self.account_id, self.project_id, self.id, filters=filters, **kwargs
+        )
+        return self.sitemaps
+
     """
     CRAWL
     """
 
     def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.crawls.DeepCrawlCrawl':
-        """Refresh crawl instance
+        """
+        Refresh crawl instance
 
         >>> self.refresh()
         [0 1 3] 2020-04-23 11:10:11+00:00
@@ -283,7 +316,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def update(
             self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.crawls.DeepCrawlCrawl':
-        """Update crawl instance
+        """
+        Update crawl instance
 
         >>> self.update(crawl_data)
         [0 1 3] 2020-04-23 11:10:11+00:00
@@ -302,7 +336,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         return self
 
     def delete(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
-        """Delete current crawl instance
+        """
+        Delete current crawl instance
 
         >>> response = self.delete()
         >>> response.status_code
@@ -324,7 +359,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def get_report(
             self, report_id: str, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlReport:
-        """Get report
+        """
+        Get report
 
         >>> self.get_report("4:duplicate_body_content:basic")
         [0 1 2] 4:duplicate_body_content:basic
@@ -343,7 +379,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlReport]:
-        """Get reports for current instance
+        """
+        Get reports for current instance
 
         * use_cache=True > get_reports will return cached reports or will do a call to DeepCrawl if reports attribute is empty.
         * use_cache=False > get_reports will call DeepCrawl api and will override reports attribute.
@@ -372,7 +409,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlReport]:
-        """Get reports changes for current instance
+        """
+        Get reports changes for current instance
 
         * use_cache=True > get_reports_changes will return cached reports changes or will do a call to DeepCrawl if reports_changes attribute is empty.
         * use_cache=False > get_reports_changes will call DeepCrawl api and will override reports_changes attribute.
@@ -405,7 +443,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawlDownloads]:
-        """Get reports downloads for current instance
+        """
+        Get reports downloads for current instance
 
         * use_cache=True > get_downloads will return cached reports downloads or will do a call to DeepCrawl if downloads attribute is empty.
         * use_cache=False > get_downloads will call DeepCrawl api and will override downloads attribute.
@@ -437,7 +476,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def get_crawl_statistic(
             self, statistic_type: str, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlCrawlStatistic:
-        """Get crawl statistic
+        """
+        Get crawl statistic
 
         >>> self.get_crawl_statistic('report_trend')
         URL Breakdown
@@ -458,7 +498,8 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawlStatistic]:
-        """Get report statistics
+        """
+        Get crawl statistics
 
         * use_cache=True > get_crawl_statistics will return cached statistics or will do a call to DeepCrawl if statistics attribute is empty.
         * use_cache=False > get_crawl_statistics will call DeepCrawl api and will override statistics attribute.
@@ -481,3 +522,36 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         if self.statistics and use_cache:
             return self.statistics
         return self.load_statistics(connection=connection, filters=filters, **kwargs)
+
+    """
+    CRAWL SITEMAPS
+    """
+
+    def get_crawl_sitemaps(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlStatistic]:
+        """
+        Get crawl sitemaps
+
+        * use_cache=True > get_crawl_sitemaps will return cached sitemaps or will do a call to DeepCrawl if sitemaps attribute is empty.
+        * use_cache=False > get_crawl_sitemaps will call DeepCrawl api and will override sitemaps attribute.
+
+        >>> self.get_crawl_sitemaps()
+        [xSbcfwBTi, aWimWxmnc]
+
+        :param use_cache:
+        :type use_cache: bool
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: List of sitemaps
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        if self.sitemaps and use_cache:
+            return self.sitemaps
+        return self.load_crawl_sitemaps(connection=connection, filters=filters, **kwargs)
