@@ -28,7 +28,7 @@ class MajesticSettings(ImmutableAttributesMixin):
 
     mutable_attributes = majestic_mutable_fields
 
-    def __init__(self, majestic_settings):
+    def __init__(self, majestic_settings: dict):
         self.enabled = majestic_settings.get("enabled")
         self.max_rows = majestic_settings.get("max_rows")
         self.use_historic_data = majestic_settings.get("use_historic_data")
@@ -40,9 +40,9 @@ class MajesticSettings(ImmutableAttributesMixin):
         super(MajesticSettings, self).__init__()
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         return {x: getattr(self, x, None) for x in majestic_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         return {x: getattr(self, x, None) for x in majestic_immutable_fields}
